notetools.make_repeated_notes_with_shorter_notes_at_end
=======================================================

.. autofunction:: abjad.tools.notetools.make_repeated_notes_with_shorter_notes_at_end.make_repeated_notes_with_shorter_notes_at_end
